bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 29. Aventiure
___________________________________________________ #### Aventivre wie hagene vnd volker #### vor chriemhilt sal sazen
###### 1758 | ### Do schieden sich di zwene | recken lobelich ### hagen von tronege | vnt ovch her dieterich ### do blichte veber ahsel | der gvntheres man ### nach einem hergesellen | den er vil schiere gewan
###### 1759 | ### do sah er voelker | bi giselhere sten ### den spaehen videlaere | bat er mit im gen ### wand er vil wol erchand | sinen grimmen mvt ### er was an allen dingen | ein ritter chvene vnd gvt
###### 1760 | ### noch liezen si di herren | vf dem hove stan ### niwan si zwene aleine | sach man dannen gan ### veber den hof vil verre | fver einen palas wit ### di vzerwelten degene | vorhten niemenes nit
###### 1761 | ### si gesazen vor dem hvse | gegen einem sal ### der was criemhilde | vf eine banch ce tal ### do lvhte in von ir libe | ir herlich gewant ### genvge da si sazen | si heten gerne bechant
###### 1762 | ### alsam tier div wilden | wurden gekapffet an ### di vebermevten helde | von den hivnen man ### si ersah ovch dvrch ein fenster | daz eceln wip ### des wart aber betrvebet | der schonen criemhilden lip
###### 1763 | ### ez mante si ir leide | weinen si began ### des hete michel wunder | di eceln man ### waz ir so schiere | betrvebet het den mvt ### si sprach daz hat hagene | ir helde chvne vnde gvt
###### 1764 | ### si sprachen zv der vrowen | wi ist daz geschehen ### wand wir ivch niwliche | haben vro gesehen ### nie niemen wart so chvene | derz iv hat getan ### heizet irz vns rechen | ez sol im an sin leben gan
###### 1765 | ### daz wold ich immer dienen | swer reche miniv leit ### alles des er gerte | des waer ich im bereit ### ich bivte mich iv ce fvzen | sprach des chvenges wip ### rechet mich an hanege | daz er vliese den lip
###### 1766 | ### do garten sich vil balde | sehzech chvner man ### dvrh crimhilde willen | si wolden hine gan ### vnd wolden slahen hagenen | den vil chvenen man ### vnd ovch den videlaere | daz wart mit rate getan
###### 1767 | ### do div chveneginne | ir shar so chleine sach ### in einem grimmem mvte | si zv den helden sprach ### des ir da habt gedingen | des svlt ir abe gan ### ia ne dvrffet ir so ringe | nimmer hagenen bestan
###### 1768 | ### swi starch vnt swi chvene | von tronege hagen si ### noch ist er verre staercher | der im da sizet bi ### volker der videlaer | der ist ein vebel man ### ia ne svlt ir di helde | niht so lihte bestan
###### 1769 | ### do si daz gehorten | do gart sich ir mer ### vier hvndert sneller recken | div kveneginne her ### was des genoete | daz si in taete leit ### davon wart sit degenen | vil michel sorge bereit
###### 1770 | ### do si vil wol gevafent | daz ir gesinde sach ### zv den snellen recken | div kveneginne sprach ### nv bitet eine wile | ia svlt ir stille stan ### ich wil vnder crone | zv minen vianden gan
###### 1771 | ### vnde hoeret itwizze | waz mir hat getan ### hagen von tronege | der gventheres man ### ich weiz in so vebermveten | daz er mir lovgent niht ### so ist ovch mir vnmaere | swaz im darvmbe geshihit
###### 1772 | ### do sach der videlaere | ein chvene spilman ### di edeln chveneginne | ab einer stiege gan ### nider von einem hvse | als er daz gesach ### voker der vil chvene | zv sinem hergesellen sprach
###### 1773 | ### nv schowet vrivnt hagene | wa si dort her gat ### div vns ane triwe | inz lant geladet hat ### ine gesach mit kvenges wibe | nie so manegen man ### di swert enhend trvegen vnd | also stritechlichen gan
###### 1774 | ### wizet ir frivnt hagene | ob si iv sin gehaz ### so wil ich iv raten | ir hvetet deste baz ### des libes vnt der eren | ia dvnchet ez mich gvt ### als ich mich versinne | si sint zornech gemvt
###### 1775 | ### vnd sint ovch svemeliche | cen brvsten also wit ### swer sin selbes hvete | der tv daz en zit ### ich waen si di liehten brvenne | nv darvnder tragen ### wen si damit meinen | daz en chan ich niemen gesagen
###### 1776 | ### do sprach in zornes mvote | hagen der chvene man ### ich weiz wol daz iz allez | ist vf mich getan ### daz si div liehten waffen | tragent an der hant ### vor den moeht ich noch geriten | in der bvrgonden lant
###### 1777 | ### nv sagt mir vrivnt volker | ob ir mir welt gestan ### ob wellent mit mir striten | di criemhilde man ### daz lazet ir mich hoeren | als lieb als ich iv si ### ich won iv immer mere | mit triwen dienstlichen bi
###### 1778 | ### ich hilf iv sicherlichen | sprach der spilman ### ob ich uns engegene | saehe den kvnech selbe gan ### mit allen sinen recken | di wile ich leben mvz ### so entwich ich iv dvrch vorhte | nimmer einen fvz
###### 1779 | ### nv lon iv got von himele | vil edel volker ### ob si mit mir striten | wes bedarf ich danne mer ### sit ir mir helffen wellet | als ich han vernomen ### so svln dise recken | wil gewaerlichen chomen
###### 1780 | ### nv ste wir von dem sedele | sprach der spilman ### si ist ein chveneginne | vnd lat si fvr gan ### bietet ir di ere | si ist ein edel wip ### damit ist ovch getivret | vnser ieweders lip
###### 1781 | ### nein dvrch mine liebe | sprach aber hagene ### so wolden sich versinnen | dise degene ### daz ichz dvrch vorhte taete | vnd sold ich hin gen ### ich en wil dvrch ir deheinen | nimmer von dem sedele sten
###### 1782 | ### ia zimet ez vns beiden | zeware lazzen daz ### zwiv sold ich den eren | der mir ist gehaz ### daz en getvn ich nimmer | di wile ich han den lip ### ovch en rvch ich waz mich genidet | des kvnech ecelen wip
###### 1783 | ### der vebermvete hagene | leit veber siniv bein ### ein vil liehtez waffen | vz des knopffe shein ### ein vil liehter iaspes | grvener danne ein gras ### wol erchand ez criemhilt | daz ez sifrides was
###### 1784 | ### do si daz swert erchande | do gi ir trvrens not ### sin gehelze daz was gvldin | div scheide ein porte rot ### ez mante si ir leide | weinen si began ### ich waene ez hete darvmbe | der chvene hagen getan
###### 1785 | ### volker der snelle | zoch naher vf der banch ### einen videlbogen starchen | vil michel vnd lanch ### gelich einem swerte | vil sharpf vnde breit ### do sazen vnder vorhte | di zwene degene gemeit
###### 1786 | ### nv dvhten sich so here | di zwene chvene man ### daz si niht wolden | von dem saedel stan ### dvrch niemens vorhte | des gie in an den fvz ### div edele chveneginne | vnd bot in vientlichen grvz
###### 1787 | ### si sprach der hagene | wer hat nach iv gesant ### daz ir getorstet riten | her in diz lant ### vnde ir daz wol erchandet | waz ir mir habet getan ### hetet ir gvete sinne | ir soldet ez pilliche lan
###### 1788 | ### nach mir sande niemen | sprach do hagene ### man ladete her ce lande | drie degene ### di heizent mine herren | vnd bin ich ir man ### in deheiner hovereise | bin ich selten hinder in bestan
###### 1789 | ### si sprach nv sagt mir mere | zwiv tatet ir daz ### daz ir daz habt verdienet | daz ich iv bin gehaz ### ir slvoget sifriden | den minen lieben man ### des ich vnz an min ende | immer genvch ce weinen han
###### 1790 | ### er sprach waz sol des mere | der rede ist nv genvch ### ich pinz aber hagene | der sifriden slvch ### den helt ce sinen handen | wi sere er des engalt ### daz div schoene criemhilt | di vrovn prvnnhilden shalt
###### 1791 | ### ez ist et ane lovgen | chvneginne rich ### ich han es alles shvlde | des schaden shedelich ### nv rechez swer der welle | ez si wip oder man ### ich en wolde danne liegen | ich han iv leides vil getan
###### 1792 | ### si sprach nv hoert ir rechen | wa er mir lovgent niht ### aller miner leide | swaz im davon gesiht ### daz ist mir vil vnmaere | ir eceln man ### di vebermveten degene | einander sahen si an
###### 1793 | ### swer den strit da hvebe | so waere daz geschehen ### daz man den zwein gesellen | der eren mvese iehen ### wan siz in stvrmen heten | vil diche wol getan ### des sich iene vermazen | dvrch vorhte mvsen si daz lan
###### 1794 | ### do sprach ein der rechen | wes seht ir mich an ### daz ich e da lobte | des wil abe gan ### daz ich dvrch niemens gabe | verliesen wil den lip ### ia wil vns verleiten | des kvnech eceln wip
###### 1795 | ### do sprach dabi ein ander | des selben han ich mvt ### der mir gaebe tverne | von rotem golde gvt ### disen videlaere | wold ich niht bestan ### dvrch sine swinden bliche | di ich an im gesehen han
###### 1796 | ### ovch erchenne ich hagenen | von sinen ivngen tagen ### des mach man von dem rechen | lihte mir gesagen ### in zwein vnd zweinzech stvrmen | han ich in gesehen ### da vil maniger vrowen | ist herceleit geschehen
###### 1797 | ### er vnt der von spanye | taten manegen stich ### do si hi bi eceln | vahten manech wich ### ce eren dem chvenege | des ist vil geschehen ### darvmb mvz man hagenen | der eren pilliche iehen
###### 1798 | ### dannoch was der reche | siner iar ein chint ### daz do di tvmben waren | wi grise di nv sint ### nv ist er chomen ce witzen | vnd ist ein grimmech man ### ovch treit er palmvngen | daz er vil vebele gewan
###### 1799 | ### damit was gescheiden | daz niemen da ne streit ### do wart der chveneginne | hercenlichen leit ### di helde cherten dannen | ia vorhten si den tot ### von dem videlaere | des gie in sicherlichen not
###### 1800 | ### do sprach der videlaere | wir haben daz wol ersehen ### daz wir hi vinde vinden | als wir e horten iehen ### wir svln zv den chvenegen | hin ce hove gan ### so ne tar vnser herren | mit strite niemen bestan
###### 1801 | ### wi dicke ein man dvrch vorhte | manigiv dinch verlat ### swa so frivnt bi frivnde | frivntlichen stat ### vnd hat er gvote sinne | daz ers nine tvt ### schade vil maniges | wirt von sinnen wol behvt
###### 1802 | ### nv wil ich iv volgen | sprach do hagene ### si giengen da si fvnden | di zieren degene ### in grozem antpfange | an dem hove stan ### volker der vil chvene | vil lvte sprechen began
###### 1803 | ### zv den sinen herren | wi lange welt ir sten ### daz ir ivch lazet dringen | ir svlt ce hove gen ### vnde horet an dem kvenege | wi er si gemvt ### do sach man sich gesellen | di helde chvene vnd gvt
###### 1804 | ### der fvrste von berne | nam an di hant ### gvntheren den vil richen | von bvrgonden lant ### irnfrit der nam gernoten | den vil chvnen man ### do sach man rvdgeren | ce hove mit giselheren gan
###### 1805 | ### swi iemen sich gesellete | vnd ovh ce hove gie ### volker vnde hagen | di geschieden sich nie ### niwan in einem stvrme | an ir endes zit ### daz mvsen edel vrowen | beweinen groezlichen sit
###### 1806 | ### do sach man mit den kvenegen | hin ce hove gan ### ir edeln ingesindes | tvsent chvener man ### darveber sehzech rechen | di waren mit in chomen ### di het in sinem lande | der chvene hagen genomen
###### 1807 | ### hawart vnd ovch irinch | di zwene vzerwelten man ### di sach man gesellichen | bi den chvenegen gan ### danchwart vnd wolfhart | ein tiwerlicher degen ### di sach man wol ir tvgende | vor den anderen pflegen
###### 1808 | ### do der vogt von rine | in den palas gie ### ecel der vil riche | daz langer niht en lie ### er spranch von sinem sedele | als er in chomen sach ### er grvz so rehte schoene | von den chvnegen im geschach
###### 1809 | ### sit willechomen her gvnther | vnd ovch her gernot ### vnd iwer brvder giselher | min dienest ich iv enbot ### mit triwen vlizechlichen | ce wormez veber rin ### vnd allez daz gesinde | sol mir willechomen sin
###### 1810 | ### nv sit vnz goze willechomen | ir zwene degene ### volker der vil chvene | vnd ovch hagene ### mir vnd miner vrowen | her in dizze lant ### si hat iv boten manige | hin ce rine gesant
###### 1811 | ### do sprach von tronege hagene | des han ich vil vernomen ### waere ich dvrch mine herren | cen hivnen her niht chomen ### so waere ich iv cen eren | geritten in daz lant ### do nam der wirt vil edele | di lieben geste bi der hant
###### 1812 | ### er brate si cem sedele | da er selbe saz ### do schancte man den gesten | mit vlize tet man daz ### in witen goldes schallen met | moraz vnde win ### vnde bat di ellenden | groze willechomen sin
###### 1813 | ### do sprach der kvnech ecel | des wil ich iv veriehen ### mir en chvnde in dirre werlde | lieber niht geschehen ### denne ovch an iv helden | daz ir mir sit bechomen ### des ist der chveneginne | vil michel trvren benomen
###### 1814 | ### mich nimt des michel wunder | waz ich iv habe getan ### so manigen gast vil edel | den ich gewunnen han ### daz ir nie gervchtet | chomen in miniv lant ### daz ich ivh nv gesehen han | daz ist cen vrevden mir gewant
###### 1815 | ### des antwurte rvedeger | ein ritter hohgemvt ### ir mvgt si sehen gerne | ir triwe div ist gvt ### der minen vrowen mage | so schone chvnnen pflegen ### si bringent iv ce hvse | vil manegen waetlichen degen
###### 1816 | ### an svnewenden abent | di herren waren chomen ### in eceln hof des richen | vil selten ist vernomen ### von also hohem grvze | als er di helde enpfie ### nv was ovch ezens zit | der rvedger mit in ce tisshe gie
###### 1817 | ### ein wirt bi sinen gesten | schoner nie gesaz ### man gab in vollechlichen | trinchen vnde maz ### alles des si gerten | des was man in bereit ### man hete von den helden | vil michel wunder geseit

<<< Übersicht <<< vorige Seite nächste Seite >>>